import { Security } from '../service/index.js';
import { Base64, JWT } from '../util/index.js';
import cors from 'cors';
import express from 'express';
class Middleware {
    static register(app) {
        app.use(cors());
        app.use(express.json());
        app.use(this.auth());
    }
    static async validateBasicAuth(req) {
        const { authorization = '', } = req.headers;
        let authorized = false;
        let reason = 'VALID_CREDENTIALS';
        if (typeof authorization === 'string' && authorization.startsWith('Basic')) {
            const credential = Base64.decode(authorization.replace('Basic ', ''), false);
            const [username = '', password = ''] = credential?.split(':') || [];
            authorized = await Security.isAuthorizedUser(username, password);
            reason = 'INVALID_CREDENTIALS';
        }
        else {
            reason = 'NOT_FOUND_CREDENTIALS';
        }
        return { authorized, reason };
    }
    static validateToken(req) {
        const { authorization = '', } = req.headers;
        if (typeof authorization === 'string' && authorization.startsWith('Bearer')) {
            const credential = authorization.replace('Bearer ', '');
            const authorized = JWT.validate(credential);
            return { authorized, reason: authorized ? 'VALID_TOKEN' : 'INVALID_TOKEN' };
        }
        return { authorized: false, reason: 'NOT_FOUND_TOKEN' };
    }
    static auth() {
        return async (req, res, next) => {
            if (Middleware.publicRoutes.includes(req.path)) {
                return next();
            }
            const basicAuthValidation = await Middleware.validateBasicAuth(req);
            if (basicAuthValidation.authorized) {
                return next();
            }
            const tokenValidation = Middleware.validateToken(req);
            if (tokenValidation.authorized) {
                return next();
            }
            res.status(401).send({
                message: 'UNAUTHORIZED',
                data: {
                    BasicAuth: basicAuthValidation.reason,
                    Token: tokenValidation.reason,
                },
            });
        };
    }
}
Middleware.publicRoutes = ['/api/version'];
export default Middleware;
