import { JWT } from '../util/index.js';
import { Security } from '../service/index.js';
class SocketMiddleware {
    static hasCredentials(socket) {
        const { handshake: { auth = null } } = socket;
        return auth && auth.username && auth.password;
    }
    static async isAuthorizedUser(socket) {
        const { username, password, } = socket.handshake.auth;
        return Security.isAuthorizedUser(username, password);
    }
    static isValidToken(socket) {
        const { token, } = socket.handshake.auth;
        return token ? JWT.validate(token) : true;
    }
    static async isValidSocketConnection(socket) {
        const hasCredentials = this.hasCredentials(socket);
        const isAuthorizedUser = await this.isAuthorizedUser(socket);
        const isValidToken = this.isValidToken(socket);
        if (!hasCredentials)
            return false;
        if (!isAuthorizedUser && !isValidToken)
            return false;
        if (isAuthorizedUser && !isValidToken) {
            delete socket.handshake.auth.token;
        }
        return true;
    }
    static register(io) {
        io.use(async (socket, next) => {
            const isValidConnection = await this.isValidSocketConnection(socket);
            if (isValidConnection) {
                if (!socket.handshake.auth.token) {
                    const token = JWT.generate({});
                    socket.emit('auth-token', token);
                }
                next();
            }
            else {
                socket.disconnect();
            }
        });
    }
}
export default SocketMiddleware;
