import { Login, ProductSetting, UpdaterVersion } from '../service/index.js';
import { Request } from '../util/index.js';
class ApiRoutes {
    register(app) {
        app.post('/api/login', async (req, res) => {
            try {
                const { agent } = req.headers;
                const response = await Login.login({ ...Request.getAllParams(req), agent });
                if (response.STATUS) {
                    res.status(200).send(response);
                }
                else {
                    res.status(500).send(response);
                }
            }
            catch (err) {
                Request.handleResponseError(res, err);
            }
        });
        app.post('/api/server', async (req, res) => {
            try {
                const response = await Login.setServerForOrganization(Request.getAllParams(req));
                res.send(response);
            }
            catch (err) {
                Request.handleResponseError(res, err);
            }
        });
        app.get('/api/product-setting', async (req, res) => {
            try {
                const response = await ProductSetting.getSettingForApi();
                res.send(response);
            }
            catch (err) {
                Request.handleResponseError(res, err);
            }
        });
        app.get('/api/updater-version/download/:version?', async (req, res) => {
            UpdaterVersion.download(Request.getAllParams(req), res);
        });
        app.get('/api/updater-approved-version', async (req, res) => {
            try {
                const response = await UpdaterVersion.list({ onlyApprovedVersion: true });
                res.send(response);
            }
            catch (err) {
                Request.handleResponseError(res, err);
            }
        });
        app.get('/api/version', async (req, res) => {
            res.status(200).send({
                version: process.env.APPLICATION_VERSION,
                environment: process.env.NODE_ENV || 'development',
            });
        });
    }
}
export default new ApiRoutes();
