import path from 'path';
import { File } from '../util/index.js';
class AssistantControl {
    async readDataBasePath() {
        const dbPath = process.env.ASSIST_CONTROL_DB_PATH;
        if (!dbPath)
            throw new Error('Variable { ASSIST_CONTROL_DB_PATH } not defined');
        const versionFolders = await File.readdir(dbPath, { onlyType: 'directory' });
        const getVersionByPath = (pathToAnalise) => path.basename(pathToAnalise.replace(path.dirname(pathToAnalise), ''));
        const handleDbFiles = (dbFiles) => ({ version: getVersionByPath(dbFiles[0].path), files: dbFiles });
        const readDbFiles = (dir) => File.readdir(path.join(dir.path, dir.name), { onlyType: 'file' }).then(handleDbFiles);
        const databaseFiles = await Promise.all(versionFolders.map(readDbFiles));
        return databaseFiles;
    }
    async getDataBaseList() {
        const dbList = await this.readDataBasePath();
        let response = [];
        dbList.forEach((versionInfo) => {
            response = response.concat(versionInfo.files.map((file) => {
                file.version = versionInfo.version;
                return file;
            }));
        });
        return response;
    }
    async downloadDb(response, { version, fileName }) {
        const dbPath = process.env.ASSIST_CONTROL_DB_PATH;
        if (!dbPath) {
            response.status(500).send({
                error: 'Variable { ASSIST_CONTROL_DB_PATH } not defined',
            });
            return;
        }
        response.download(path.join(dbPath, version, fileName), (err) => {
            if (err) {
                console.error(`Erro ao realizar download da versão ${fileName}`, err);
                response.status(500).send({
                    error: `Error ao processar download. Err: ${err.message}`,
                    stack: err.stack,
                    version,
                    fileName,
                });
            }
        });
    }
}
export default new AssistantControl();
